---
title: Dokime
emoji: 🌾
colorFrom: purple
colorTo: blue
sdk: gradio
sdk_version: "4.44.1"
app_file: app.py
pinned: false
license: apache-2.0
short_description: Open-source data curation toolkit for ML training data
---
